@@ -1,8 +1,13 @@
+"""Init for nerdchess.
+
+When ran standalone opens a small TUI game of chess.
+"""
 from nerdchess import game
 from tabulate import tabulate
 
 
 def main():
+    """Play a gane of chess."""
     name_1 = input('What is the name of player 1?')
     name_1_color = input(
         "With which color should {} start, (w)hite, (b)lack or (r)andom?\
